# vla-evaluation-harness

**One framework to evaluate any VLA model on any robot simulation benchmark.**

> 🚧 This package is under active development. A functional release is coming soon.

## License

MIT

